@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  mod_ssl.c 
+**  Apache API interface structures
 */
 
 /* ====================================================================
@@ -56,14 +58,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-                                      /*
-                                       * I cannot write a program which is
-                                       * as popular as one from Larry Wall.
-                                       * But I can write one which is from me.
-                                       *                     -- RSE
-                                       */
-
+                             /* ``I'll be surprised if 
+                                  others think that what you 
+                                  are doing is honourable.''
+                                    -- Ben Laurie, Apache-SSL author */
 #include "mod_ssl.h"
 
 /*  _________________________________________________________________
