@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  mod_ssl.h
+**  Global header
 */
 
 /* ====================================================================
@@ -56,15 +58,11 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-                                      /*
-                                       * The Apache Group: a collection of
-                                       * talented individuals who are trying
-                                       * to perfect the art of never finishing
-                                       * something.
-                                       *              -- Rob Hartill
-                                       */
-
+                             /* ``The Apache Group: a collection 
+                                  of talented individuals who are 
+                                  trying to perfect the art of 
+                                  never finishing something.''
+                                             -- Rob Hartill         */
 #ifndef MOD_SSL_H
 #define MOD_SSL_H 1
 
