@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_compat.c
+**  Backward Compatibility
 */
 
 /* ====================================================================
@@ -57,6 +59,10 @@
  * ====================================================================
  */
 
+                             /* ``Backward compatibility is for 
+                                  users who don't want to live
+                                  on the bleeding edge.''
+                                            -- Unknown          */
 #ifdef SSL_COMPAT
 
 #include "mod_ssl.h"
@@ -314,91 +320,106 @@ char *ssl_compat_directive(server_rec *s, pool *p, const char *oline)
  * The mapping of obsolete environment variables to official ones...
  */
 
+#define VRM_BEGIN              /* nop */
+#define VRM_ENTRY(var,action)  { var, action },
+#define VRM_END                { NULL, NULL, NULL }
+#define VRM_VAR(old)           old
+#define VRM_SUB(new)           new, NULL
+#define VRM_LOG(msg)           NULL, msg
+
 static struct {
-    enum { VRM_END, VRM_SUB, VRM_MSG } nType;
     char *cpOld;
+    char *cpMsg;
     char *cpNew;
 } ssl_var_rewrite_map[] = {
+    VRM_BEGIN
+
     /* 
-     * Apache-SSL 1.x, mod_ssl 2.0.x, Sioux 1.x and Stronghold 2.x backward compatibility
+     * Apache-SSL 1.x, mod_ssl 2.0.x, Sioux 1.x 
+     * and Stronghold 2.x backward compatibility
      */
-    { VRM_SUB, "SSL_PROTOCOL_VERSION",          "SSL_PROTOCOL"              },
-    { VRM_SUB, "SSLEAY_VERSION",                "SSL_VERSION_LIBRARY"       },
-    { VRM_SUB, "HTTPS_SECRETKEYSIZE",           "SSL_CIPHER_USEKEYSIZE"     },
-    { VRM_SUB, "HTTPS_KEYSIZE",                 "SSL_CIPHER_ALGKEYSIZE"     },
-    { VRM_SUB, "HTTPS_CIPHER",                  "SSL_CIPHER"                },
-    { VRM_SUB, "HTTPS_EXPORT",                  "SSL_CIPHER_EXPORT"         },
-    { VRM_SUB, "SSL_SERVER_KEY_SIZE",           "SSL_CIPHER_ALGKEYSIZE"     },
-    { VRM_SUB, "SSL_SERVER_CERTIFICATE",        "SSL_SERVER_CERT"           },
-    { VRM_SUB, "SSL_SERVER_CERT_START",         "SSL_SERVER_V_START"        },
-    { VRM_SUB, "SSL_SERVER_CERT_END",           "SSL_SERVER_V_END"          },
-    { VRM_SUB, "SSL_SERVER_CN",                 "SSL_SERVER_S_DN_CN"        },
-    { VRM_SUB, "SSL_SERVER_EMAIL",              "SSL_SERVER_S_DN_Email"     },
-    { VRM_SUB, "SSL_SERVER_O",                  "SSL_SERVER_S_DN_O"         },
-    { VRM_SUB, "SSL_SERVER_OU",                 "SSL_SERVER_S_DN_OU"        },
-    { VRM_SUB, "SSL_SERVER_C",                  "SSL_SERVER_S_DN_C"         },
-    { VRM_SUB, "SSL_SERVER_SP",                 "SSL_SERVER_S_DN_SP"        },
-    { VRM_SUB, "SSL_SERVER_L",                  "SSL_SERVER_S_DN_L"         },
-    { VRM_SUB, "SSL_SERVER_ICN",                "SSL_SERVER_I_DN_CN"        },
-    { VRM_SUB, "SSL_SERVER_IEMAIL",             "SSL_SERVER_I_DN_Email"     },
-    { VRM_SUB, "SSL_SERVER_IO",                 "SSL_SERVER_I_DN_O"         },
-    { VRM_SUB, "SSL_SERVER_IOU",                "SSL_SERVER_I_DN_OU"        },
-    { VRM_SUB, "SSL_SERVER_IC",                 "SSL_SERVER_I_DN_C"         },
-    { VRM_SUB, "SSL_SERVER_ISP",                "SSL_SERVER_I_DN_SP"        },
-    { VRM_SUB, "SSL_SERVER_IL",                 "SSL_SERVER_I_DN_L"         },
-    { VRM_SUB, "SSL_CLIENT_CERTIFICATE",        "SSL_CLIENT_CERT"           },
-    { VRM_SUB, "SSL_CLIENT_CERT_START",         "SSL_CLIENT_V_START"        },
-    { VRM_SUB, "SSL_CLIENT_CERT_END",           "SSL_CLIENT_V_END"          },
-    { VRM_SUB, "SSL_CLIENT_CN",                 "SSL_CLIENT_S_DN_CN"        },
-    { VRM_SUB, "SSL_CLIENT_EMAIL",              "SSL_CLIENT_S_DN_Email"     },
-    { VRM_SUB, "SSL_CLIENT_O",                  "SSL_CLIENT_S_DN_O"         },
-    { VRM_SUB, "SSL_CLIENT_OU",                 "SSL_CLIENT_S_DN_OU"        },
-    { VRM_SUB, "SSL_CLIENT_C",                  "SSL_CLIENT_S_DN_C"         },
-    { VRM_SUB, "SSL_CLIENT_SP",                 "SSL_CLIENT_S_DN_SP"        },
-    { VRM_SUB, "SSL_CLIENT_L",                  "SSL_CLIENT_S_DN_L"         },
-    { VRM_SUB, "SSL_CLIENT_ICN",                "SSL_CLIENT_I_DN_CN"        },
-    { VRM_SUB, "SSL_CLIENT_IEMAIL",             "SSL_CLIENT_I_DN_Email"     },
-    { VRM_SUB, "SSL_CLIENT_IO",                 "SSL_CLIENT_I_DN_O"         },
-    { VRM_SUB, "SSL_CLIENT_IOU",                "SSL_CLIENT_I_DN_OU"        },
-    { VRM_SUB, "SSL_CLIENT_IC",                 "SSL_CLIENT_I_DN_C"         },
-    { VRM_SUB, "SSL_CLIENT_ISP",                "SSL_CLIENT_I_DN_SP"        },
-    { VRM_SUB, "SSL_CLIENT_IL",                 "SSL_CLIENT_I_DN_L"         },
-    { VRM_MSG, "SSL_SERVER_KEY_EXP",            "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_KEY_ALGORITHM",      "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_SIGNATURE_ALGORITHM","Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_SESSIONDIR",         "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_CERTIFICATELOGDIR",  "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_CERTFILE",           "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_KEYFILE",            "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_SERVER_KEYFILETYPE",        "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_CLIENT_KEY_EXP",            "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_CLIENT_KEY_ALGORITHM",      "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_CLIENT_KEY_SIZE",           "Not supported by mod_ssl"  },
-    { VRM_MSG, "SSL_CLIENT_SIGNATURE_ALGORITHM","Not supported by mod_ssl"  },
-    /*
-     * End of map.
-     */
-    { VRM_END, NULL, NULL }
+    VRM_ENTRY( VRM_VAR("SSL_PROTOCOL_VERSION"),          VRM_SUB("SSL_PROTOCOL")             )
+    VRM_ENTRY( VRM_VAR("SSLEAY_VERSION"),                VRM_SUB("SSL_VERSION_LIBRARY")      )
+    VRM_ENTRY( VRM_VAR("HTTPS_SECRETKEYSIZE"),           VRM_SUB("SSL_CIPHER_USEKEYSIZE")    )
+    VRM_ENTRY( VRM_VAR("HTTPS_KEYSIZE"),                 VRM_SUB("SSL_CIPHER_ALGKEYSIZE")    )
+    VRM_ENTRY( VRM_VAR("HTTPS_CIPHER"),                  VRM_SUB("SSL_CIPHER")               )
+    VRM_ENTRY( VRM_VAR("HTTPS_EXPORT"),                  VRM_SUB("SSL_CIPHER_EXPORT")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_KEY_SIZE"),           VRM_SUB("SSL_CIPHER_ALGKEYSIZE")    )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CERTIFICATE"),        VRM_SUB("SSL_SERVER_CERT")          )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CERT_START"),         VRM_SUB("SSL_SERVER_V_START")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CERT_END"),           VRM_SUB("SSL_SERVER_V_END")         )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CN"),                 VRM_SUB("SSL_SERVER_S_DN_CN")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_EMAIL"),              VRM_SUB("SSL_SERVER_S_DN_Email")    )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_O"),                  VRM_SUB("SSL_SERVER_S_DN_O")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_OU"),                 VRM_SUB("SSL_SERVER_S_DN_OU")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_C"),                  VRM_SUB("SSL_SERVER_S_DN_C")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_SP"),                 VRM_SUB("SSL_SERVER_S_DN_SP")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_L"),                  VRM_SUB("SSL_SERVER_S_DN_L")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_ICN"),                VRM_SUB("SSL_SERVER_I_DN_CN")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_IEMAIL"),             VRM_SUB("SSL_SERVER_I_DN_Email")    )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_IO"),                 VRM_SUB("SSL_SERVER_I_DN_O")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_IOU"),                VRM_SUB("SSL_SERVER_I_DN_OU")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_IC"),                 VRM_SUB("SSL_SERVER_I_DN_C")        )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_ISP"),                VRM_SUB("SSL_SERVER_I_DN_SP")       )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_IL"),                 VRM_SUB("SSL_SERVER_I_DN_L")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_CERTIFICATE"),        VRM_SUB("SSL_CLIENT_CERT")          )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_CERT_START"),         VRM_SUB("SSL_CLIENT_V_START")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_CERT_END"),           VRM_SUB("SSL_CLIENT_V_END")         )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_CN"),                 VRM_SUB("SSL_CLIENT_S_DN_CN")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_EMAIL"),              VRM_SUB("SSL_CLIENT_S_DN_Email")    )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_O"),                  VRM_SUB("SSL_CLIENT_S_DN_O")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_OU"),                 VRM_SUB("SSL_CLIENT_S_DN_OU")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_C"),                  VRM_SUB("SSL_CLIENT_S_DN_C")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_SP"),                 VRM_SUB("SSL_CLIENT_S_DN_SP")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_L"),                  VRM_SUB("SSL_CLIENT_S_DN_L")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_ICN"),                VRM_SUB("SSL_CLIENT_I_DN_CN")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_IEMAIL"),             VRM_SUB("SSL_CLIENT_I_DN_Email")    )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_IO"),                 VRM_SUB("SSL_CLIENT_I_DN_O")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_IOU"),                VRM_SUB("SSL_CLIENT_I_DN_OU")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_IC"),                 VRM_SUB("SSL_CLIENT_I_DN_C")        )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_ISP"),                VRM_SUB("SSL_CLIENT_I_DN_SP")       )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_IL"),                 VRM_SUB("SSL_CLIENT_I_DN_L")        )
+
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_KEY_EXP"),            VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_KEY_ALGORITHM"),      VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_SIGNATURE_ALGORITHM"),VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_SESSIONDIR"),         VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CERTIFICATELOGDIR"),  VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_CERTFILE"),           VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_KEYFILE"),            VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_SERVER_KEYFILETYPE"),        VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_KEY_EXP"),            VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_KEY_ALGORITHM"),      VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_KEY_SIZE"),           VRM_LOG("Not supported by mod_ssl") )
+    VRM_ENTRY( VRM_VAR("SSL_CLIENT_SIGNATURE_ALGORITHM"),VRM_LOG("Not supported by mod_ssl") )
+
+    VRM_END
 };
 
 void ssl_compat_variables(request_rec *r)
 {
     char *cpOld;
     char *cpNew;
+    char *cpMsg;
     char *cpVal;
     int i;
 
-    for (i = 0; ssl_var_rewrite_map[i].nType != VRM_END; i++) {
+    for (i = 0; ssl_var_rewrite_map[i].cpOld != NULL; i++) {
         cpOld = ssl_var_rewrite_map[i].cpOld;
+        cpMsg = ssl_var_rewrite_map[i].cpMsg;
         cpNew = ssl_var_rewrite_map[i].cpNew;
-        if (ssl_var_rewrite_map[i].nType == VRM_SUB) {
+        if (cpNew != NULL) {
             cpVal = ssl_var_lookup(r->pool, r->server, r->connection, r, cpNew);
             if (!strIsEmpty(cpVal))
                 ap_table_set(r->subprocess_env, cpOld, cpVal);
             break;
         }
-        else if (ssl_var_rewrite_map[i].nType == VRM_MSG) {
-            ap_table_set(r->subprocess_env, cpOld, cpNew);
+        else if (cpMsg != NULL) {
+            /* 
+             * we cannot print a message, so we at least the
+             * variables contents to the message
+             */
+            ap_table_set(r->subprocess_env, cpOld, cpMsg);
             break;
         }
     }
