@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_config.c
+**  Apache Configuration Directives
 */
 
 /* ====================================================================
@@ -57,12 +59,9 @@
  * ====================================================================
  */
 
-                                      /*
-                                       * Damned if you do, 
-                                       * damned if you don't 
-                                       *       -- unknown
-                                       */
-
+                                      /* ``Damned if you do, 
+                                           damned if you don't.''
+                                               -- Unknown        */
 #include "mod_ssl.h"
 
 
