@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_ext.c
+**  Extensions to other Apache parts
 */
 
 /* ====================================================================
@@ -56,8 +58,9 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``Only those who attempt the absurd
+                                  can achieve the impossible.''  
+                                           -- Unknown             */
 #include "mod_ssl.h"
 
 
