@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_io.c
+**  I/O Functions
 */
 
 /* ====================================================================
@@ -56,8 +58,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``MY HACK: This universe.
+                                  Just one little problem: 
+                                  core keeps dumping.''
+                                            -- Unknown    */
 #include "mod_ssl.h"
 
 
@@ -101,8 +105,18 @@ static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
     SSL *ssl;
     int rc;
 
-    if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL)
+    if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_read(ssl, buf, len);
+        if (rc < 0)
+            rc = -1;
+        /* 
+         * Simulate an EINTR in case SSLeay wants to read more.  
+         * (This is usually the case when the client forces an SSL
+         * renegotation which is handled implicitly by SSLeay.)
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_READ)
+            errno = EINTR;
+    }
     else
         rc = read(fb->fd_in, buf, len);
     return rc;
@@ -113,8 +127,16 @@ static int ssl_io_hook_write(BUFF *fb, char *buf, int len)
     SSL *ssl;
     int rc;
 
-    if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL)
+    if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_write(ssl, buf, len);
+        if (rc < 0)
+            rc = -1;
+        /* 
+         * Simulate an EINTR in case SSLeay wants to write more.  
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
+            errno = EINTR;
+    }
     else
         rc = write(fb->fd, buf, len);
     return rc;
@@ -131,6 +153,13 @@ static int ssl_io_hook_writev(BUFF *fb, const struct iovec *iov, int iovcnt)
 
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_writev(ssl, iov, iovcnt);
+        if (rc < 0)
+            rc = -1;
+        /* 
+         * Simulate an EINTR in case SSLeay wants to write more.  
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
+            errno = EINTR;
     }
     else 
         rc = writev(fb->fd, iov, iovcnt);
@@ -375,12 +404,14 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
 long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long len)
 {
     SSL *ssl;
+    conn_rec *c;
     server_rec *s;
 
     if ((ssl = (SSL *)BIO_get_callback_arg(bio)) == NULL)
         return len;
-    if ((s = (server_rec *)SSL_get_app_data(ssl)) == NULL)
+    if ((c = (conn_rec *)SSL_get_app_data(ssl)) == NULL)
         return len;
+    s = c->server;
 
     if (cmd == (BIO_CB_READ|BIO_CB_RETURN)) {
         ssl_log(s, SSL_LOG_DEBUG, 
