@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_kernel.c
+**  The SSL engine kernel
 */
 
 /* ====================================================================
@@ -100,14 +102,11 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-                                      /*
-                                       * It took me fifteen years to discover
-                                       * I had no talent for programming, but
-                                       * I couldn't give it up because by that
-                                       * time I was too famous.
-                                       *                     -- unknown
-                                       */
+                             /* ``It took me fifteen years to discover
+                                  I had no talent for programming, but
+                                  I couldn't give it up because by that
+                                  time I was too famous.''
+                                            -- Unknown                */
 #include "mod_ssl.h"
 
 
@@ -175,7 +174,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
      * so we can detach later.
      */
     ssl = SSL_new(sc->pSSLCtx);
-    SSL_set_app_data(ssl, srvr);
+    SSL_set_app_data(ssl, conn);
     SSL_set_fd(ssl, fb->fd);
     ap_ctx_set(fb->ctx, "ssl", ssl);
     ap_register_cleanup(conn->pool, (void *)conn, 
@@ -348,17 +347,6 @@ void ssl_hook_NewConnection(conn_rec *conn)
             fb->flags |= B_EOF|B_EOUT;
             return;
         }
-
-        /*
-         * Finally log the connection details
-         */
-        ssl_log(srvr, SSL_LOG_INFO, 
-                "Client IP: %s, Protocol: %s, Cipher: %s (%s/%s bits)", 
-                ssl_var_lookup(NULL, NULL, conn, NULL, "REMOTE_ADDR"),
-                ssl_var_lookup(NULL, NULL, conn, NULL, "SSL_PROTOCOL"),
-                ssl_var_lookup(NULL, NULL, conn, NULL, "SSL_CIPHER"),
-                ssl_var_lookup(NULL, NULL, conn, NULL, "SSL_CIPHER_USEKEYSIZE"),
-                ssl_var_lookup(NULL, NULL, conn, NULL, "SSL_CIPHER_ALGKEYSIZE"));
     }
 
     /* 
@@ -893,6 +881,7 @@ void ssl_callback_DelSessionCacheEntry(
  */
 void ssl_callback_LogTracingState(SSL *ssl, int where, int rc)
 {
+    conn_rec *c;
     server_rec *s;
     SSLSrvConfigRec *sc;
     char *str;
@@ -900,44 +889,57 @@ void ssl_callback_LogTracingState(SSL *ssl, int where, int rc)
     /* 
      * find corresponding server
      */
-    if ((s = (server_rec *)SSL_get_app_data(ssl)) == NULL)
+    if ((c = (conn_rec *)SSL_get_app_data(ssl)) == NULL)
         return;
-
-    /*
-     * pre-check the logging level to avoid processing overhead
-     */
+    s = c->server;
     if ((sc = mySrvConfig(s)) == NULL)
         return;
-    if (sc->nLogLevel < SSL_LOG_TRACE)
-        return;
 
     /* 
      * create the various trace messages
      */
-    if (where & SSL_CB_HANDSHAKE_START)
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: start");
-    else if (where & SSL_CB_HANDSHAKE_DONE)
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: done");
-    else if (where & SSL_CB_LOOP)
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Loop: %s", SSL_state_string_long(ssl));
-    else if (where & SSL_CB_READ)
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Read: %s", SSL_state_string_long(ssl));
-    else if (where & SSL_CB_WRITE)
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Write: %s", SSL_state_string_long(ssl));
-    else if (where & SSL_CB_ALERT) {
-        str = (where & SSL_CB_READ) ? "read" : "write";
-        ssl_log(s, SSL_LOG_TRACE, "SSLeay: Alert: %s:%s\n",
-                SSL_alert_type_string_long(rc), 
-                SSL_alert_desc_string_long(rc));
+    if (sc->nLogLevel >= SSL_LOG_TRACE) {
+        if (where & SSL_CB_HANDSHAKE_START)
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: start");
+        else if (where & SSL_CB_HANDSHAKE_DONE)
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: done");
+        else if (where & SSL_CB_LOOP)
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Loop: %s", SSL_state_string_long(ssl));
+        else if (where & SSL_CB_READ)
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Read: %s", SSL_state_string_long(ssl));
+        else if (where & SSL_CB_WRITE)
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Write: %s", SSL_state_string_long(ssl));
+        else if (where & SSL_CB_ALERT) {
+            str = (where & SSL_CB_READ) ? "read" : "write";
+            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Alert: %s:%s\n",
+                    SSL_alert_type_string_long(rc), 
+                    SSL_alert_desc_string_long(rc));
+        }
+        else if (where & SSL_CB_EXIT) {
+            if (rc == 0)
+                ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: failed in %s\n",
+                        SSL_state_string_long(ssl));
+            else if (rc < 0)
+                ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: error in %s\n",
+                        SSL_state_string_long(ssl));
+        }
     }
-    else if (where & SSL_CB_EXIT) {
-        if (rc == 0)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: failed in %s\n",
-                    SSL_state_string_long(ssl));
-        else if (rc < 0)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: error in %s\n",
-                    SSL_state_string_long(ssl));
+
+    /*
+     * Because SSL renegotations can happen at any time (not only after
+     * SSL_accept()), the best way to log the current connection details is
+     * right after a finished handshake.
+     */
+    if (where & SSL_CB_HANDSHAKE_DONE) {
+        ssl_log(s, SSL_LOG_INFO, 
+                "Connection: Client IP: %s, Protocol: %s, Cipher: %s (%s/%s bits)", 
+                ssl_var_lookup(NULL, s, c, NULL, "REMOTE_ADDR"),
+                ssl_var_lookup(NULL, s, c, NULL, "SSL_PROTOCOL"),
+                ssl_var_lookup(NULL, s, c, NULL, "SSL_CIPHER"),
+                ssl_var_lookup(NULL, s, c, NULL, "SSL_CIPHER_USEKEYSIZE"),
+                ssl_var_lookup(NULL, s, c, NULL, "SSL_CIPHER_ALGKEYSIZE"));
     }
+
     return;
 }
 
