@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_mutex.c
+**  Semaphore for Mutual Exclusion
 */
 
 /* ====================================================================
@@ -56,8 +58,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``Real programmers confuse 
+                                  Christmas and Halloween 
+                                  because DEC 25 = OCT 31.''
+                                             -- Unknown     */
 #include "mod_ssl.h"
 
 
