@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_pphrase.c
+**  Pass Phrase Dialog
 */
 
 /* ====================================================================
@@ -56,14 +58,11 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-                                      /*
-                                       * Treat your password like your
-                                       * toothbrush.  Don't let anybody else
-                                       * use it, and get a new one every six
-                                       * months.   
-                                       *            -- Clifford Stoll
-                                       */
+                             /* ``Treat your password like your
+                                  toothbrush. Don't let anybody 
+                                  else use it, and get a new one 
+                                  every six months.''
+                                           -- Clifford Stoll     */
 #include "mod_ssl.h"
 
 
