@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_scache.c
+**  Session Cache
 */
 
 /* ====================================================================
@@ -56,14 +58,11 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-  
-                                      /*
-                                       * Open-Source Software: generous
-                                       * programmers from around the world all
-                                       * join forces to help you shoot
-                                       * yourself in the foot for free.
-                                       *           -- unknown
-                                       */
+                             /* ``Open-Source Software: generous
+                                  programmers from around the world all
+                                  join forces to help you shoot
+                                  yourself in the foot for free.''
+                                                 -- Unknown         */
 #include "mod_ssl.h"
 
 
