@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_engine_vars.c
+**  Variable Lookup Facility
 */
 
 /* ====================================================================
@@ -56,8 +58,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``Those of you who think they
+                                  know everything are very annoying 
+                                  to those of us who do.''
+                                                  -- Unknown       */
 #include "mod_ssl.h"
 
 
