@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_expr.c
+**  Expression Handling
 */
 
 /* ====================================================================
@@ -56,8 +58,10 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``It is hard to fly with
+                                  the eagles when you work 
+                                  with the turkeys.''
+                                          -- Unknown  */
 #include "mod_ssl.h"
 
 
