@@ -4,6 +4,8 @@
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
 **                      |_____|         
+**  ssl_util.c
+**  Utility Functions
 */
 
 /* ====================================================================
@@ -100,8 +102,11 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-
-
+                             /* ``Every day of my life
+                                  I am forced to add another 
+                                  name to the list of people 
+                                  who piss me off!''
+                                            -- Calvin          */
 #include "mod_ssl.h"
 
 
